@@ -4,7 +4,7 @@ package UNIVERSAL::Object;
 use strict;
 use warnings;
 
-our $VERSION   = '0.02';
+our $VERSION   = '0.03';
 our $AUTHORITY = 'cpan:STEVAN';
 
 BEGIN {
@@ -16,7 +16,7 @@ sub new {
     my $class = shift;
        $class = ref $class if ref $class;
     my $proto = $class->BUILDARGS( @_ );
-    my $self  = $class->CREATE( $proto );
+    my $self  = $class->BLESS( $proto );
     $self->can('BUILD') && UNIVERSAL::Object::Util::BUILDALL( $self, $proto );
     return $self;
 }
@@ -35,7 +35,7 @@ sub BUILDARGS {
     }
 }
 
-sub CREATE {
+sub BLESS {
     my $class = $_[0];
        $class = ref $class if ref $class;
     my $proto = $_[1];
@@ -43,7 +43,15 @@ sub CREATE {
     die '[ARGS] You must specify an instance prototype as a HASH ref'
         unless $proto && ref $proto eq 'HASH';
 
-    my $self  = {};
+    return bless $class->CREATE( $proto ) => $class;
+}
+
+sub CREATE {
+    my $class = $_[0];
+       $class = ref $class if ref $class;
+    my $proto = $_[1];
+
+    my $self  = $class->REPR;
     my %slots = $class->SLOTS;
 
     $self->{ $_ } = exists $proto->{ $_ }
@@ -51,9 +59,11 @@ sub CREATE {
         : $slots{ $_ }->( $self, $proto )
             foreach keys %slots;
 
-    return bless $self => $class;
+    return $self;
 }
 
+sub REPR () { +{} }
+
 sub SLOTS {
     my $class = $_[0];
        $class = ref $class if ref $class;
@@ -71,7 +81,8 @@ sub DESTROY {
 ## Utils
 
 sub UNIVERSAL::Object::Util::BUILDALL {
-    my ($self, $proto) = @_;
+    my $self  = $_[0];
+    my $proto = $_[1];
     foreach my $super ( reverse @{ mro::get_linear_isa( ref $self ) } ) {
         my $fully_qualified_name = $super . '::BUILD';
         $self->$fully_qualified_name( $proto )
@@ -80,7 +91,7 @@ sub UNIVERSAL::Object::Util::BUILDALL {
 }
 
 sub UNIVERSAL::Object::Util::DEMOLISHALL {
-    my ($self) = @_;
+    my $self = $_[0];
     foreach my $super ( @{ mro::get_linear_isa( ref $self ) } ) {
         my $fully_qualified_name = $super . '::DEMOLISH';
         $self->$fully_qualified_name()
@@ -100,7 +111,7 @@ UNIVERSAL::Object - A useful base class
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -188,6 +199,21 @@ or store them in a different form (not C<< key => CODE >> hash
 entries), it is possible to then override this method to return the
 expected values in the expected form.
 
+=head1 INSTANCE REPRESENTATION
+
+=head2 C<REPR>
+
+This returns a new HASH reference to use as the instance.
+
+B<NOTE:>
+If you wish to use a different instance type of some kind then you
+will need to override this method.
+
+B<NOTE:>
+The HASH that gets returned from here will eventually be blessed,
+which means you are limited to C<tie> or XS C<MAGIC> based solutions
+if you want this HASH reference to behave differently.
+
 =head1 CONSTRUCTION PROTOCOL
 
 Once we know the expected slots it is very easy to create a default
@@ -210,33 +236,52 @@ should always be a fully constructed and initialized instance.
 This method takes the original C<@args> to the C<new> constructor
 and is expected to turn them into a canonical form, which is a
 HASH ref of name/value pairs. This form is considered a prototype
-candidate for the instance, and subseqently what C<CREATE> expects
-to receive.
+candidate for the instance, and what C<BLESS> and suseqently 
+C<CREATE> expect to receive.
 
 B<NOTE:>
 The values in the prototype candidate should be shallow copies of
 what was originally contained in C<@args>, but this is not actually
 enforced, just suggested to provide better ownership distinctions.
 
-=head2 C<CREATE ($class, $proto)>
+=head2 C<BLESS ($class, $proto)>
 
 This method receives the C<$proto> candidate from C<BUILDARGS> and
-constructs from it a blessed instance of the class.
+from it, ultimately constructs a blessed instance of the class.
 
-First it must call C<SLOTS> (described above), then it will use the
-returned slot definitions along with the C<$proto> candidate to
-construct a complete blessed instance. It does this by looping
-through the list of slots, using values in the C<$proto> when
-available, otherwise using the slot initializers. The final blessed
-HASH ref based instance is then returned.
+This method really has two responsibilities, first is to call 
+C<CREATE>, passing it the C<$proto> instance. Then it will take 
+the return value of C<CREATE> and C<bless> it into the C<$class>. 
 
 B<NOTE:>
-If you wish to use a different instance type or some kind then this
-is the method you want to override.
+This method is mostly here to make it easier to override the 
+C<CREATE> method, which, along with the C<REPR> method, can be 
+used to change the behavior and/or type of the instance 
+structure. By keeping the C<bless> work here we make the work 
+done in C<CREATE> simpler with less mechanics. 
+
+=head2 C<CREATE ($class, $proto)>
+
+This method receives the C<$proto> candidate from C<BLESS> and
+return from it an unblessed instance structure that C<BLESS> will 
+then C<bless> into the C<$class>.
+
+First it must call C<SLOTS> (described above), followed by C<REPR>
+(also described above) to get both the slot definitions and a newly
+minted HASH ref instance. Using these two things, along with the
+C<$proto> candidate, we construct a complete blessed instance.
+This is accomplished by looping through the list of slots, using
+values in the C<$proto> when available, otherwise using the slot
+initializers. The final unblessed HASH ref based instance is then
+returned.
+
+B<NOTE:>
+If you wish to use a different instance type of some kind then you
+will need to override this method.
 
 =head2 C<BUILD ($self, $proto)>
 
-The newly blessed instance supplied by C<CREATE> must still be
+The newly blessed instance supplied by C<BLESS> must still be
 initialized. We do this by calling all the available C<BUILD> methods
 in the inheritance hierarchy in the correct (reverse mro) order.
 
